﻿using Syncfusion.DocIO;
using Syncfusion.DocIO.DLS;
using System.Web.Mvc;
using Syncfusion.OfficeChart;
using System.Collections.Generic;
using System.Drawing;

namespace CreateWordSample.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
           
            return View();
        }
        public ActionResult CreateDocument()
        {
            string input = Server.MapPath(@"..//Data//Input.docx").ToString();
            WordDocument document = new WordDocument(input);
            //Processes the body contents for each section in the Word document
            foreach (WSection section in document.Sections)
            {
                //Accesses the Body of section where all the contents in document are apart
                WTextBody sectionBody = section.Body;
                IterateTextBody(sectionBody);
            }
            //Saves and closes the document instance
            document.Save("Result.docx", FormatType.Docx, HttpContext.ApplicationInstance.Response, HttpContentDisposition.Attachment);
            document.Close();

            return View();
        }
        private static void IterateTextBody(WTextBody textBody)
        {
            //Iterates through each of the child items of WTextBody
            for (int i = 0; i < textBody.ChildEntities.Count; i++)
            {
                //IEntity is the basic unit in DocIO DOM. 
                //Accesses the body items (should be either paragraph or table) as IEntity
                IEntity bodyItemEntity = textBody.ChildEntities[i];
                //A Text body has 2 types of elements - Paragraph and Table
                //Decides the element type by using EntityType
                switch (bodyItemEntity.EntityType)
                {
                    case EntityType.Paragraph:
                        WParagraph paragraph = bodyItemEntity as WParagraph;
                        //Checks for particular style name and removes the paragraph from DOM
                        if (paragraph.StyleName == "Heading 1")
                        {
                            //Displays in output Window
                            System.Diagnostics.Debug.WriteLine(paragraph.Text);
                        }
                        else
                            System.Diagnostics.Debug.WriteLine(paragraph.Text);
                        break;
                    case EntityType.Table:
                        //Table is a collection of rows and cells
                        //Iterates through table's DOM
                        IterateTable(bodyItemEntity as WTable);
                        break;
                }
            }
        }
        private static void IterateTable(WTable table)
        {
            //Iterates the row collection in a table
            foreach (WTableRow row in table.Rows)
            {
                //Iterates the cell collection in a table row
                foreach (WTableCell cell in row.Cells)
                {
                    //Table cell is derived from (also a) TextBody
                    //Reusing the code meant for iterating TextBody
                    IterateTextBody(cell);
                }
            }
        }
        //Get the path for Word template document
        protected string ResolveApplicationDataPath(string fileName)
        {
            //Data folder path is resolved from requested page physical path.
            string dataPath = new System.IO.DirectoryInfo(Request.PhysicalPath + "..\\..\\Data\\").FullName;
            return string.Format("{0}\\{1}", dataPath, fileName);
        }

        public ActionResult About()
        {
            ViewBag.Message = "Your application description page.";

            return View();
        }

        public ActionResult Contact()
        {
            ViewBag.Message = "Your contact page.";

            return View();
        }
    }
}